@@ -1,6 +1,8 @@
 
-import warnings, datetime
+import warnings, datetime, inspect
 import bpyth as bpy
+from IPython.display import Markdown
+
 
 #############################################################################################################
 ### blab_startup
@@ -34,6 +36,10 @@ def run_notebooks( exclude=[], out_dir = 'nb_out/', mode='list', cell_timeout=No
     
     import os   
     
+    # exclude: force list
+    if isinstance(exclude, str):
+        exclude = [exclude]
+    
     # Create
     if not os.path.exists(out_dir):
         os.makedirs(out_dir) 
@@ -93,15 +99,23 @@ def run_notebooks( exclude=[], out_dir = 'nb_out/', mode='list', cell_timeout=No
 ### search_code
 #############################################################################################################    
 
-def search_notebooks( query, radius=1, exclude=[]):
+def search_notebooks( query, radius=1, exclude=[], suffix='ipynb'):
     '''
     Searches notebooks for occurrences of a string.
     Not only the code, but also all output is searched.
     The search is case sensitive.
-    radius=1: In the whole workspace
-    radius=0: In the current directory
+    * radius=0: In the current directory    
+      radius=1: One dir up and recursive all descendants
+      ...
+      radius=5: Five dirs up and recursive all descendants    
+    * exclude: List of strings that must not appear in the file name
+    * suffix:  file suffix. suffix='py' searches for python files. 
     '''
     
+    # exclude: force list
+    if isinstance(exclude, str):
+        exclude = [exclude]    
+    
     import glob
     def suche_intern(query,pattern):
         result = []
@@ -118,9 +132,17 @@ def search_notebooks( query, radius=1, exclude=[]):
                 
     result = []
     if (radius == 0):
-        pattern = '*.ipynb'
+        pattern = '*.' + suffix
+    elif (radius == 1):
+        pattern = '../**/*.' + suffix
+    elif (radius == 2):
+        pattern = '../../**/*.' + suffix   
+    elif (radius == 3):
+        pattern = '../../../**/*.' + suffix    
+    elif (radius == 4):
+        pattern = '../../../../**/*.' + suffix
     else:
-        pattern = '../**/*.ipynb'
+        pattern = '../../../../../**/*.ipynb'              
     result += suche_intern(query,pattern)
     
     result += ['----------------------------------']
@@ -142,3 +164,13 @@ def search_notebooks( query, radius=1, exclude=[]):
     
     
     
+#############################################################################################################
+### render_doc
+#############################################################################################################     
+
+def render_doc(obj):
+    '''
+    Renders the docstring of an object as Markdown.<br>
+    Example: `blab.render_doc( blab.render_doc )`
+    '''
+    return display(Markdown(inspect.getdoc(obj)))
\ No newline at end of file
